@@ -5,14 +5,14 @@ OBIS:   https://api.obis.org/
 WoRMS: http://marinespecies.org/rest/
 """
 
-import requests
-import logging
 import concurrent.futures
+import logging
 from functools import lru_cache
 
-import shapely.geometry as sh_geo
-import pandas as pd
 import numpy as np
+import pandas as pd
+import requests
+import shapely.geometry as sh_geo
 
 
 @lru_cache(None)
@@ -56,9 +56,10 @@ def request_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
     results_dfs = []
     retry_counter = 5  # max number of request retry when Timeout error
     if eco_code and aphia_id:
-        logging.error('Either eco_code or aphiaID can be specified. Not both')
-        raise NotImplementedError('Either ecocode or aphiaID can be specified.'
-                                  'Not both')
+        logging.error("Either eco_code or aphiaID can be specified. Not both")
+        raise NotImplementedError(
+            "Either ecocode or aphiaID can be specified." "Not both"
+        )
 
     if eco_code:
         # the import here is because of circular import - marine_life imports
@@ -66,8 +67,9 @@ def request_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
         # We need only this one method.
         # TODO find better way in order to remove circular import
         from marinvaders.marinelife import marine_ecoregions
+
         gdf = marine_ecoregions(eco_code=eco_code)
-        geometry = gdf.iloc[0]['geometry']
+        geometry = gdf.iloc[0]["geometry"]
 
         def _round_remove_duplicates(array):
             """
@@ -86,102 +88,123 @@ def request_obis(eco_code: int = None, aphia_id: int = None) -> pd.DataFrame:
             return retval
 
         geosjson = sh_geo.mapping(geometry)
-        if geosjson['type'] == 'MultiPolygon':
+        if geosjson["type"] == "MultiPolygon":
             coordinates = []
-            for coord in geosjson['coordinates']:
+            for coord in geosjson["coordinates"]:
                 res = _round_remove_duplicates(coord[0])
                 coordinates.append([res])
-            geosjson['coordinates'] = coordinates
-        elif geosjson['type'] == 'Polygon':
-            res = _round_remove_duplicates(geosjson['coordinates'][0])
-            geosjson['coordinates'] = [res]
+            geosjson["coordinates"] = coordinates
+        elif geosjson["type"] == "Polygon":
+            res = _round_remove_duplicates(geosjson["coordinates"][0])
+            geosjson["coordinates"] = [res]
         else:
-            raise ValueError('Geometry must be either Polygon or MultiPolygon.'
-                             'Current type is: {}'.format(geosjson['type']))
+            raise ValueError(
+                "Geometry must be either Polygon or MultiPolygon."
+                "Current type is: {}".format(geosjson["type"])
+            )
         geometry = sh_geo.shape(geosjson)
 
         if not geometry.is_valid:
-            raise RuntimeError('The geometry is not valid shape object.')
-        _val = ('geometry', geometry)
+            raise RuntimeError("The geometry is not valid shape object.")
+        _val = ("geometry", geometry)
     elif aphia_id:
-        _val = ('taxonid', aphia_id)
+        _val = ("taxonid", aphia_id)
     else:
-        raise ValueError('Either geometry or aphiaID must be specified')
+        raise ValueError("Either geometry or aphiaID must be specified")
 
     while True:
         try:
             r = requests.get(
-                'https://api.obis.org/v3/occurrence?&{}={}&size={}&after={}'
-                .format(_val[0], _val[1], size, after))
+                "https://api.obis.org/v3/occurrence?&{}={}&size={}&after={}".format(
+                    _val[0], _val[1], size, after
+                )
+            )
         except requests.exceptions.HTTPError as e:
-            logging.error('HTTPSError: {}'.format(e))
+            logging.error("HTTPSError: {}".format(e))
             break
         except requests.exceptions.Timeout as e:
-            logging.error('Timeout Exception: {}'.format(e))
+            logging.error("Timeout Exception: {}".format(e))
             if retry_counter == 0:
-                logging.warning('Tried already 5 times. Quiting')
+                logging.warning("Tried already 5 times. Quiting")
                 break
-            logging.info('Retrying obis request')
+            logging.info("Retrying obis request")
             retry_counter -= 1
         except Exception as e:
-            logging.error('Something went wrong. error: {}, '
-                          'response code: {}, response text: {}'.format(
-                              e, r.status_code, r.text))
+            logging.error(
+                "Something went wrong. error: {}, "
+                "response code: {}, response text: {}".format(e, r.status_code, r.text)
+            )
             break
         else:
             if r.status_code == 200:
                 res_json = r.json()
-                if not len(res_json['results']):
+                if not len(res_json["results"]):
                     break
-                _data = res_json['results']
-                after = _data[-1]['id']
-                _data = [dict(id=item['id'],
-                              aphiaID=item['aphiaID'],
-                              species=item['species'],
-                              decimalLatitude=item['decimalLatitude'],
-                              decimalLongitude=item['decimalLongitude'])
-                         for item in _data if 'aphiaID' in item and 'species'
-                         in item]
+                _data = res_json["results"]
+                after = _data[-1]["id"]
+                _data = [
+                    dict(
+                        id=item["id"],
+                        aphiaID=item["aphiaID"],
+                        species=item["species"],
+                        decimalLatitude=item["decimalLatitude"],
+                        decimalLongitude=item["decimalLongitude"],
+                    )
+                    for item in _data
+                    if "aphiaID" in item and "species" in item
+                ]
                 # process only if not empty record is returned from request
                 if _data:
                     df = pd.DataFrame.from_dict(_data)
-                    df = df.dropna(subset=['species'])
-                    df = df[['aphiaID', 'species', 'decimalLatitude',
-                             'decimalLongitude']]
+                    df = df.dropna(subset=["species"])
+                    df = df[
+                        ["aphiaID", "species", "decimalLatitude", "decimalLongitude"]
+                    ]
                     results_dfs.append(df)
             elif r.status_code == 400:
-                # the geometry of selected area is huge and we need some tricks
-                # to dealt with it.
-                # First select bounding box and then filter out species outside
-                # of the origin geometry.
+                # the geometry of selected area is huge (with a lot fo points)
+                # and we need some tricks to deal with it.
+                # So first we select bounding box and then we filter out
+                # species outside of the origin geometry.
                 area_too_big = True
                 minx, miny, maxx, maxy = geometry.bounds
-                geometry = sh_geo.Polygon([(minx, miny), (maxx, miny),
-                                           (maxx, maxy), (minx, maxy),
-                                           (minx, miny)])
-                _val = ('geometry', geometry)
+                geometry = sh_geo.Polygon(
+                    [
+                        (minx, miny),
+                        (maxx, miny),
+                        (maxx, maxy),
+                        (minx, maxy),
+                        (minx, miny),
+                    ]
+                )
+                _val = ("geometry", geometry)
             else:
-                str_val = 'eco_code {}'.format(eco_code) if eco_code \
-                    else 'aphiaID: {}'.format(aphia_id)
-                _msg = 'OBIS API for {} returned code: {} - {}'\
-                    .format(str_val, r.status_code, r.text)
+                str_val = (
+                    "eco_code {}".format(eco_code)
+                    if eco_code
+                    else "aphiaID: {}".format(aphia_id)
+                )
+                _msg = "OBIS API for {} returned code: {} - {}".format(
+                    str_val, r.status_code, r.text
+                )
                 raise RuntimeError(_msg)
 
     df_obis = pd.concat(results_dfs, sort=True)
-    df_obis['aphiaID'] = df_obis['aphiaID'].fillna(-1)
-    df_obis['aphiaID'] = df_obis['aphiaID'].astype('int64')
+    df_obis["aphiaID"] = df_obis["aphiaID"].fillna(-1)
+    df_obis["aphiaID"] = df_obis["aphiaID"].astype("int64")
 
     df_obis.drop_duplicates(inplace=True)
 
     if area_too_big:
-        geometry = gdf.iloc[0]['geometry']
-        df_obis['is_within_polygon'] = df_obis.apply(
-            lambda x: sh_geo.Point(x['decimalLongitude'],
-                                   x['decimalLatitude']
-                                   ).within(geometry), axis=1)
-        df_obis = df_obis[df_obis['is_within_polygon'] is True]
-        df_obis = df_obis[['aphiaID', 'species',
-                           'decimalLatitude', 'decimalLongitude']]
+        geometry = gdf.iloc[0]["geometry"]
+        df_obis["is_within_polygon"] = df_obis.apply(
+            lambda x: sh_geo.Point(x["decimalLongitude"], x["decimalLatitude"]).within(
+                geometry
+            ),
+            axis=1,
+        )
+        df_obis = df_obis[df_obis["is_within_polygon"] is True]
+        df_obis = df_obis[["aphiaID", "species", "decimalLatitude", "decimalLongitude"]]
 
     return df_obis.reset_index()
 
@@ -208,33 +231,37 @@ def _fetch_worms(aphia_id: int) -> pd.DataFrame:
     pandas DataFrame
     """
     try:
-        r = \
-            requests.get(
-                'http://marinespecies.org/rest/AphiaDistributionsByAphiaID/{}'
-                .format(aphia_id))
+        r = requests.get(
+            "http://marinespecies.org/rest/AphiaDistributionsByAphiaID/{}".format(
+                aphia_id
+            )
+        )
     except Exception as e:
         # no record found for this AphiaID
         if r.status_code == 204:
-            logging.warning('WoRMS request for AphiaID: {} returned response_'
-                            'code 204 - '
-                            'No Content.'.format(aphia_id))
+            logging.warning(
+                "WoRMS request for AphiaID: {} returned response_"
+                "code 204 - "
+                "No Content.".format(aphia_id)
+            )
         else:
-            logging.error('WoRMS request Error: AphaID: {}, Error: {}, '
-                          'Response: {}'
-                          .format(aphia_id, e, r))
+            logging.error(
+                "WoRMS request Error: AphaID: {}, Error: {}, "
+                "Response: {}".format(aphia_id, e, r)
+            )
         return pd.DataFrame()
     else:
         if r.status_code == 200:
-            logging.info('WoRMS API call SUCCESS for aphia ID: {}'
-                         .format(aphia_id))
+            logging.info("WoRMS API call SUCCESS for aphia ID: {}".format(aphia_id))
             x = r.json()
             df = pd.DataFrame(x)
-            df['aphiaID'] = aphia_id
+            df["aphiaID"] = aphia_id
             return df
         else:
-            logging.warning('WoRMS API call failed for AphiID: {}, '
-                            'reason: {} - {}'
-                            .format(aphia_id, r.status_code, r.reason))
+            logging.warning(
+                "WoRMS API call failed for AphiID: {}, "
+                "reason: {} - {}".format(aphia_id, r.status_code, r.reason)
+            )
             # returning empty DataFrame will fix error when
             # concatenating them later
             return pd.DataFrame()
@@ -259,22 +286,21 @@ def request_worms(aphia_ids: int) -> pd.DataFrame:
 
     with concurrent.futures.ThreadPoolExecutor() as executor:
         # Start the load operations and mark each future with its URL
-        future_to_url = {executor.submit(_fetch_worms, aphia_id): aphia_id
-                         for aphia_id in aphia_ids}
+        future_to_url = {
+            executor.submit(_fetch_worms, aphia_id): aphia_id for aphia_id in aphia_ids
+        }
         for future in concurrent.futures.as_completed(future_to_url):
             aphia_id = future_to_url[future]
             try:
                 data = future.result()
                 results_dfs.append(data)
             except Exception as e:
-                logging.error('{} generated an exception: {}'
-                              .format(aphia_id, e))
+                logging.error("{} generated an exception: {}".format(aphia_id, e))
 
     try:
         df_worms = pd.concat(results_dfs)
     except Exception as e:
-        logging.info('No data found in WoRMS. Exception: {}'
-                     .format(e))
+        logging.info("No data found in WoRMS. Exception: {}".format(e))
         return pd.DataFrame()
     else:
         return df_worms
