@@ -10,6 +10,7 @@ from enum import Enum
 from functools import lru_cache
 
 import pandas as pd
+
 import geopandas as gpd
 
 
@@ -29,12 +30,11 @@ class ShapeFiles(Enum):
     """
     Enum of shape files directory.
     """
-    MEOW_ECOS: os.path = os.path.join('meow_ecos', 'meow_ecos.shp')
-    EEZ: os.path = os.path.join('eez_low_res', 'eez_lr.shp')
-    EEZ_IHO_UNION: os.path = \
-        os.path.join('EEZ_IHO_union_v2', 'EEZ_IHO_union_v2.shp')
-    IHO_SEA_AREAS: os.path = \
-        os.path.join('IHO Sea Areas', 'World_Seas_IHO_v3.shp')
+
+    MEOW_ECOS: os.path = os.path.join("meow_ecos", "meow_ecos.shp")
+    EEZ: os.path = os.path.join("eez_low_res", "eez_lr.shp")
+    EEZ_IHO_UNION: os.path = os.path.join("EEZ_IHO_union_v2", "EEZ_IHO_union_v2.shp")
+    IHO_SEA_AREAS: os.path = os.path.join("IHO Sea Areas", "World_Seas_IHO_v3.shp")
 
 
 @lru_cache(None)
@@ -54,11 +54,10 @@ def read_shapefile(shape_name: ShapeFiles) -> gpd.GeoDataFrame:
     gdf = gpd.read_file(os.path.join(data_path(), shape_name.value))
 
     if shape_name == ShapeFiles.MEOW_ECOS:
-        for colname in ['ECO_CODE', 'PROV_CODE', 'RLM_CODE',
-                        'ALT_CODE', 'ECO_CODE_X']:
-            gdf[colname] = gdf[colname].astype('int')
+        for colname in ["ECO_CODE", "PROV_CODE", "RLM_CODE", "ALT_CODE", "ECO_CODE_X"]:
+            gdf[colname] = gdf[colname].astype("int")
     else:
-        gdf['MRGID'] = gdf['MRGID'].astype('int')
+        gdf["MRGID"] = gdf["MRGID"].astype("int")
 
     return gdf
 
@@ -72,27 +71,33 @@ def read_gisd_worms_link() -> pd.DataFrame:
     -------
     pd.DataFrame
     """
-    df = pd.read_excel(os.path.join(data_path(),
-                                    'GISD_and_WoRMS_qualitative_distributions_'
-                                    'linked_to_MEOWs.xlsx'),
-                       skiprows=5, engine='openpyxl')
-    df['ECO_CODE_X'] = df['ECO_CODE_X'].str.replace('.', ',')
+    df = pd.read_excel(
+        os.path.join(
+            data_path(),
+            "GISD_and_WoRMS_qualitative_distributions_" "linked_to_MEOWs.xlsx",
+        ),
+        skiprows=5,
+        engine="openpyxl",
+    )
+    df["ECO_CODE_X"] = df["ECO_CODE_X"].str.replace(".", ",")
 
     return df
 
 
 @lru_cache(None)
-def read_molnar() -> pd.DataFrame:
+def read_natcon() -> pd.DataFrame:
     """
-    Reads Molnar dataset.
+    Reads NatCon dataset.
 
     Returns
     -------
     pd.DataFrame
     """
-    df = pd.read_excel(os.path.join(data_path(), 'molnar.xlsx'),
-                       sheet_name='Species_distribution',
-                       engine='openpyxl')
+    df = pd.read_excel(
+        os.path.join(data_path(), "natcon.xlsx"),
+        sheet_name="Species_distribution",
+        engine="openpyxl",
+    )
 
     return df
 
@@ -106,7 +111,7 @@ def read_gisd() -> pd.DataFrame:
     -------
     pd.DataFrame
     """
-    df = pd.read_json(os.path.join(data_path(), 'gisd.json'))
+    df = pd.read_json(os.path.join(data_path(), "gisd.json"))
 
     return df
 
@@ -121,8 +126,8 @@ def eco_mrgid_link() -> pd.DataFrame:
     -------
     pd.DataFrame
     """
-    df = pd.read_hdf(os.path.join(data_path(), 'eco_mrgid.h5'))
-    df['MRGID'] = df['MRGID'].astype('int64')
+    df = pd.read_hdf(os.path.join(data_path(), "eco_mrgid.h5"))
+    df["MRGID"] = df["MRGID"].astype("int64")
 
     return df
 
@@ -136,8 +141,10 @@ def read_taxonomy() -> pd.DataFrame:
     -------
     Pandas DataFrame
     """
-    df = pd.read_csv(os.path.join(data_path(), 'taxonomy.csv'))
-    df = df[['scientificName']]
-    df['species'] = df['scientificName']
-    df.drop(['scientificName'], axis=1, inplace=True)
+
+    # TODO: what is taxonomy doing? Ask Francesca? Independent of Eco-region
+    df = pd.read_csv(os.path.join(data_path(), "taxonomy.csv"))
+    df = df[["scientificName"]]
+    df["species"] = df["scientificName"]
+    df.drop(["scientificName"], axis=1, inplace=True)
     return df
