@@ -1,8 +1,7 @@
 import sys
-
 import pandas as pd
 
-sys.path.append('..')
+sys.path.append("..")
 
 import marinvaders.marinelife as ml  # noqa: E402
 import marinvaders.readers as readers  # noqa: E402
@@ -14,9 +13,14 @@ def test_ecoregions():
     """
     marine_ecoregions = ml.marine_ecoregions()
     assert len(marine_ecoregions) > 0
-    assert ['ECO_CODE', 'ECO_CODE_X', 'ECOREGION',
-            'PROVINCE', 'REALM',
-            'geometry'] == list(marine_ecoregions.columns)
+    assert [
+        "ECO_CODE",
+        "ECO_CODE_X",
+        "ECOREGION",
+        "PROVINCE",
+        "REALM",
+        "geometry",
+    ] == list(marine_ecoregions.columns)
 
 
 def test_species_class():
@@ -24,7 +28,7 @@ def test_species_class():
     test instance of Species object for random species which we assume
     is always present at obis
     """
-    ds = ml.Species(145634)
+    ds = ml.Species("urn:lsid:marinespecies.org:taxname:145634")
     assert ds.aphia_id == 145634
     assert len(ds.obis) > 0
     assert isinstance(ds.obis, pd.DataFrame)
@@ -48,16 +52,16 @@ def test_readers():
 
     taxonomy = readers.read_taxonomy()
     assert isinstance(taxonomy, pd.DataFrame)
-    assert 'species' in taxonomy.columns
+    assert "species" in taxonomy.columns
     assert len(taxonomy) > 0
 
     gisd = readers.read_gisd()
     assert isinstance(gisd, pd.DataFrame)
     assert len(gisd) > 0
 
-    molnar = readers.read_molnar()
-    assert isinstance(molnar, pd.DataFrame)
-    assert len(molnar) > 0
+    natcon = readers.read_natcon()
+    assert isinstance(natcon, pd.DataFrame)
+    assert len(natcon) > 0
 
     gisd_worms_link = readers.read_gisd_worms_link()
     assert isinstance(gisd_worms_link, pd.DataFrame)
